@@ -2,11 +2,13 @@
 
 from __future__ import absolute_import
 
-from fleece.handlers.connexion import *
 import fleece.log
+from fleece.handlers.connexion import *
 
 logger = fleece.log.get_logger(__name__)
 
 
-logger.warning("fleece.connexion has been moved to fleece.handlers.connexion "
-               "- please update as this will not work in future versions.")
+logger.warning(
+    "fleece.connexion has been moved to fleece.handlers.connexion "
+    "- please update as this will not work in future versions."
+)
